********
Glossary
********

.. glossary::

    Devpi
        A powerful :term:`PyPi`-compatible server and a complimentary command
        line tool to drive packaging, testing and release activities with
        :term:`Python`.

        .. seealso::

            * `Official devpi documentation <http://doc.devpi.net/>`__

    Entry-Points
        Entry points are a mechanism for an installed distribution to advertise
        components it provides to be discovered and used by other code.

        .. seealso::

            `Entry points specification
            <https://packaging.python.org/specifications/entry-points>`_

    extras_require
        :term:`Setuptools` provides an ``extras_require`` option which takes
        a dictionary mapping unique keywords to a list of optional dependencies.

        .. seealso::

            `Setuptools - Optional Dependencies
            <https://setuptools.readthedocs.io/en/latest/userguide/
            dependency_management.html#optional-dependencies>`_

    Pip
        A recommended tool for installing :term:`Python` packages.

        .. seealso:: https://pip.pypa.io

    Python
        A programming language that lets you work quickly and integrate systems
        more effectively.

        .. seealso:: https://www.python.org/

    PyPi
        The Python Package Index (PyPI) is a repository of software for the
        Python programming language.

        .. seealso:: https://pypi.org/

    Setuptools
        Setuptools is a library designed to facilitate packaging of Python
        projects.

        .. seealso:: https://setuptools.readthedocs.io/en/latest/

    Virtualenv
        A tool to create isolated Python environments.

        .. seealso:: https://virtualenv.pypa.io/en/latest/

    Wiz
        Package manager to run command in reliable environment.

        .. seealso:: :ref:`wiz:main`
